==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/product/admin_specials.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_specials.lang.inc.php 2018-12-06
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'HEADING_SUB_TITLE'                      => 'Artikelkatalog',
	'HEADING_TITLE'                          => 'Sonderangebote',
	'TABLE_HEADING_ACTION'                   => 'Aktion',
	'TABLE_HEADING_PRODUCTS'                 => 'Artikel',
	'TABLE_HEADING_PRODUCTS_MODEL'           => 'Artikel-Nr.',
	'TABLE_HEADING_PRODUCTS_PRICE'           => 'Artikelpreis',
	'TABLE_HEADING_STATUS'                   => 'Status',
	'TEXT_IMAGE_NONEXISTENT'                 => 'Kein Bild verfügbar!',
	'TEXT_INFO_BEGINS_EXPIRES_DATE'          => 'autom. Aktivierung/ Deaktivierung',
	'TEXT_INFO_BULK_DELETE_INTRO'            => 'Sind Sie sicher, dass Sie die Sonderangebote für folgende Artikel löschen möchten?',
	'TEXT_INFO_DATE_ADDED'                   => 'hinzugefügt am',
	'TEXT_INFO_DELETE_INTRO'                 => 'Sind Sie sicher, dass Sie das Sonderangebot löschen möchten?',
	'TEXT_INFO_HEADING_BULK_DELETE_SPECIALS' => 'Sonderangebote löschen',
	'TEXT_INFO_HEADING_DELETE_SPECIALS'      => 'Sonderangebot löschen',
	'TEXT_INFO_LAST_MODIFIED'                => 'letzte Änderung',
	'TEXT_INFO_NEW_PRICE'                    => 'neuer Preis:',
	'TEXT_INFO_ORIGINAL_PRICE'               => 'alter Preis:',
	'TEXT_INFO_PERCENTAGE'                   => 'Prozent',
	'TEXT_INFO_STATUS_CHANGE'                => 'Status geändert',
	'TEXT_MARKED_ELEMENTS'                   => 'Markiertes Element',
	'TEXT_SPECIALS_BEGINS_DATE'              => 'Automatische Aktivierung am:<br />(tt.mm.jjjj)',
	'TEXT_SPECIALS_BEGINS_DATE_TIP'          => 'Angebotspreis wird an diesem Datum automatisch aktiviert; lassen Sie das Feld leer für manuelle Aktivierung. Automatische Aktivierung findet nur statt, wenn das Deaktivierungsdatum nach dem Aktivierungsdatum liegt oder leer gelassen wird.',
	'TEXT_SPECIALS_DATE_TIP'                 => 'Lassen Sie das Feld leer, wenn der Angebotspreis zeitlich unbegrenzt gelten soll.',
	'TEXT_SPECIALS_EXPIRES_DATE'             => 'Automatische Deaktivierung am:<br />(tt.mm.jjjj)',
	'TEXT_SPECIALS_PRICE_TIP'                => 'Sie können im Feld Angebotspreis auch prozentuale Werte angeben, z. B.: <b>20%</b><br /><br />Wenn Sie einen neuen Preis eingeben, müssen die Nachkommastellen mit einem "." getrennt werden, z. B.: <b>49.99</b>',
	'TEXT_SPECIALS_PRODUCT'                  => 'Artikel:',
	'TEXT_SPECIALS_SPECIAL_PRICE'            => 'Angebotspreis:',
	'TEXT_SPECIALS_SPECIAL_QUANTITY'         => 'Anzahl:',
	'TEXT_SPECIALS_STATUS'                   => 'Status:',
	'TEXT_SPECIALS_STATUS_TIP'               => 'Aktivierungsstatus des Angebotes; wird ggf. von automatischer De-/Aktivierung geändert.',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/product/admin_specials.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_specials.lang.inc.php 2018-12-06
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'HEADING_SUB_TITLE'                      => 'Artikelkatalog',
	'HEADING_TITLE'                          => 'Sonderangebote',
	'TABLE_HEADING_ACTION'                   => 'Aktion',
	'TABLE_HEADING_PRODUCTS'                 => 'Artikel',
	'TABLE_HEADING_PRODUCTS_MODEL'           => 'Artikel-Nr.',
	'TABLE_HEADING_PRODUCTS_PRICE'           => 'Artikelpreis',
	'TABLE_HEADING_STATUS'                   => 'Status',
	'TEXT_IMAGE_NONEXISTENT'                 => 'Kein Bild verfügbar!',
	'TEXT_INFO_BEGINS_EXPIRES_DATE'          => 'autom. Aktivierung/ Deaktivierung',
	'TEXT_INFO_BULK_DELETE_INTRO'            => 'Bist du sicher, dass du die Sonderangebote für folgende Artikel löschen möchtest?',
	'TEXT_INFO_DATE_ADDED'                   => 'hinzugefügt am',
	'TEXT_INFO_DELETE_INTRO'                 => 'Bist sicher, dass du das Sonderangebot löschen möchtest?',
	'TEXT_INFO_HEADING_BULK_DELETE_SPECIALS' => 'Sonderangebote löschen',
	'TEXT_INFO_HEADING_DELETE_SPECIALS'      => 'Sonderangebot löschen',
	'TEXT_INFO_LAST_MODIFIED'                => 'letzte Änderung',
	'TEXT_INFO_NEW_PRICE'                    => 'neuer Preis:',
	'TEXT_INFO_ORIGINAL_PRICE'               => 'alter Preis:',
	'TEXT_INFO_PERCENTAGE'                   => 'Prozent',
	'TEXT_INFO_STATUS_CHANGE'                => 'Status geändert',
	'TEXT_MARKED_ELEMENTS'                   => 'Markiertes Element',
	'TEXT_SPECIALS_BEGINS_DATE'              => 'Automatische Aktivierung am:<br />(tt.mm.jjjj)',
	'TEXT_SPECIALS_BEGINS_DATE_TIP'          => 'Angebotspreis wird an diesem Datum automatisch aktiviert; lasse das Feld leer für manuelle Aktivierung. Automatische Aktivierung findet nur statt, wenn das Deaktivierungsdatum nach dem Aktivierungsdatum liegt oder leer gelassen wird.',
	'TEXT_SPECIALS_DATE_TIP'                 => 'Lasse das Feld leer, wenn der Angebotspreis zeitlich unbegrenzt gelten soll.',
	'TEXT_SPECIALS_EXPIRES_DATE'             => 'Automatische Deaktivierung am:<br />(tt.mm.jjjj)',
	'TEXT_SPECIALS_PRICE_TIP'                => 'Du kannst im Feld Angebotspreis auch prozentuale Werte angeben, z. B.: <b>20%</b><br /><br />Wenn du einen neuen Preis eingibst, müssen die Nachkommastellen mit einem "." getrennt werden, z. B.: <b>49.99</b>',
	'TEXT_SPECIALS_PRODUCT'                  => 'Artikel:',
	'TEXT_SPECIALS_SPECIAL_PRICE'            => 'Angebotspreis:',
	'TEXT_SPECIALS_SPECIAL_QUANTITY'         => 'Anzahl:',
	'TEXT_SPECIALS_STATUS'                   => 'Status:',
	'TEXT_SPECIALS_STATUS_TIP'               => 'Aktivierungsstatus des Angebotes; wird ggf. von automatischer De-/Aktivierung geändert.',
];
